<?php
/**
 * @package WordPress
 * @subpackage BuddyPress
 * @sub-subpackage BP Xtra Signup
 * @author Boris Glumpler
 * @copyright 2010, ShabuShabu Webdesign
 * @link http://shabushabu.eu/bp-xtra-signup
 * @license http://www.opensource.org/licenses/gpl-2.0.php GPL License
 */

/**
* Add custom userdata from register.php
* @since 1.0
*/
function bpxs_add_to_signup( $usermeta )
{
	global $bpxs;
	
	if( (bool)$bpxs->options->tos == true )
		$usermeta['accept_tos'] = $_POST['accept_tos'];

	if( (bool)$bpxs->options->newsletter == true )
	{
		if( isset( $_POST['newsletter'] ) )
			$usermeta['newsletter'] = $_POST['newsletter'];
	}
	
	return $usermeta;
}
add_filter( 'bp_signup_usermeta', 'bpxs_add_to_signup' );

/**
* Perform checks for custom registration data
* @since 1.0
*/
function bpxs_check_additional_signup()
{
	global $bp, $bpxs;
	
	if( (bool)$bpxs->options->tos == true )
	{
		if( $_POST['accept_tos'] != 'agreed'  )
			$bp->signup->errors['accept_tos'] = stripcslashes( $bpxs->options->tos_error_text );
	}
}
add_action( 'bp_signup_validate', 'bpxs_check_additional_signup' );

/**
* Update usermeta with custom registration data
* @since 1.0
*/
function bpxs_user_activate_fields( $user_id, $user_login, $user_password, $user_email, $usermeta )
{
	global $bpxs;
	
	if( (bool)$bpxs->options->tos == true )
		update_usermeta( $user_id, 'accept_tos', $usermeta['accept_tos'] );

	if( (bool)$bpxs->options->newsletter == true )
		update_usermeta( $user_id, 'newsletter', $usermeta['newsletter'] );
	
	return $user_id;
}
add_action( 'bp_core_signup_user', 'bpxs_user_activate_fields', 5, 5 );

/**
* Subscribes a user to our newsletter if checked
* @since 4.0
*/
function bpxs_subscribe_newsletter( $user_id, $user_login, $user_password, $user_email, $usermeta )
{
	global $bpxs;
	
	if( (bool)$bpxs->options->newsletter == true )
	{
		if( $usermeta['newsletter'] == 'agreed' )
		{
			require_once( BPXS_ABSPATH . '_inc/MCAPI.class.php' );
		
			$api = new MCAPI( $bpxs->options->mcapi_key );
			
			$u = get_userdata( $user_id );
			
			$merge_vars = array( 'FNAME' => $u->nickname, 'LNAME'=> '' );
			
			$retval = $api->listSubscribe( $bpxs->options->mcapi_list_id, $u->user_email, $merge_vars );
			
			if( $api->errorCode && ! empty( $bpxs->options->email_recipient ) )
			{
				$body = stripcslashes( $bpxs->options->email_message );
				$body = str_replace( '{ERROR_CODE}', $api->errorCode, $body );
				$body = str_replace( '{ERROR_MESSAGE}', $api->errorMessage, $body );
				$body = str_replace( '{USER_ID}', $user['user_id'], $body );
				$body = str_replace( '{USER_NAME}', $auth->nickname, $body );
				$body = str_replace( '{USER_EMAIL}', $auth->user_email, $body );
	
				wp_mail( $bpxs->options->email_recipient, $bpxs->options->email_subject, $body );
			}
		}
		else
			update_usermeta( $user_id, 'newsletter', 'declined' );
	}
}
add_action( 'bp_core_signup_user', 'bpxs_subscribe_newsletter', 10, 5 );

/**
 * Add newsletter and TOS to register page
 * @since 1.0
 */
function bpxs_add_to_registration()
{
	global $bpxs;
	
	if( ! empty( $bpxs->options->tos_link ) )
	{
		$link = str_replace( '{url}', '<a href="'. $bpxs->options->tos_link .'">', stripcslashes( $bpxs->options->tos_text ) );
		$link = str_replace( '{/url}', '</a>', $link );
	}
	else
		$link = stripcslashes( $bpxs->options->tos_text );
	
	?>
    <div id="tos" class="register-section">
        <h4><?php echo stripcslashes( $bpxs->options->signup_title ) ?></h4>
        
        <?php if( (bool)$bpxs->options->tos == true ) { ?>
			<?php do_action( 'bp_accept_tos_errors' ) ?>
            <label><input type="checkbox" name="accept_tos" id="accept_tos" value="agreed" /> <?php echo $link ?></label>
		<?php } ?>

        <?php if( (bool)$bpxs->options->newsletter == true ) { ?>
            <label><input type="checkbox" name="newsletter" id="newsletter" checked="checked" value="agreed" /> <?php echo stripcslashes( $bpxs->options->newsletter_text ) ?></label>
		<?php } ?>
    </div>
    <?php
}
add_action( 'bp_before_registration_submit_buttons', 'bpxs_add_to_registration' );


?>