<?php
/**
 * @package WordPress
 * @subpackage BuddyPress
 * @sub-subpackage BP Xtra Signup
 * @author Boris Glumpler
 * @copyright 2010, ShabuShabu Webdesign
 * @link http://shabushabu.eu/bp-xtra-signup
 * @license http://www.opensource.org/licenses/gpl-2.0.php GPL License
 */
 
class BPXS_Options
{
	var $price_url;
	var $filepath;
	
	/**
	 * Constructor
	 * @since 1.0
	 */
    function __construct()
	{
		global $bpxs;
		
	    $this->filepath = admin_url() . 'admin.php?page=' . $_GET['page'];
		$this->price_url = $bpxs->home_url . 'prices.php';
        
		// only process if $_POST vars are available
		if( ! empty( $_POST ) )
			$this->processor();
    }

	/**
	 * Process any $_POST variables
	 * @since 1.0
	 */
	function processor()
	{
		global $bpxs;
		
		if ( isset( $_POST['updateoption'] ) )
		{	
			check_admin_referer( 'bpxs_settings' );
			
			$error = false;
			$message = '';

			if( $_POST['newsletter'] && ( ! $_POST['mcapi_list_id'] || ! $_POST['mcapi_key'] ) )
			{
				$message .= __( 'You need to enter a Mailchimp List ID and an API Key.', 'bpgs' );
				$error = true;
			}
			
			if( ! empty( $_POST['email_recipient'] ) )
			{
				if( ! is_email( $_POST['email_recipient'] ) )
				{
					$message .= __( 'You need to enter a valid email address.', 'bpgs' );
					$error = true;
				}
			}

			// proceed if there is no error
			if( ! $error )
			{
				if( $_POST['page_options'] )	
					$options = explode( ',', stripslashes( $_POST['page_options'] ) );
					
				if( $options )
				{
					foreach( $options as $option )
					{
						$option = trim( $option );
						$value = trim( $_POST[$option] );
						
						$bpxs->options->{$option} = $value;
					}
				}
				// Save options
				update_option( 'bpxs_options', $bpxs->options );
				
				BPXS_Admin_Loader::show_message( __( 'Update Successfully', 'bpxs' ) );
			}
			// or show any errors
			else
			{
				BPXS_Admin_Loader::show_error( $message );
			}
		}
		do_action( 'bpxs_update_options_page' );
	}
	
	/**
	 * Render the page content
	 * @since 1.0
	 */
	function controller()
	{
        // get list of tabs
        $tabs = $this->tabs_order();
		?>
        
		<script type="text/javascript">
		jQuery(document).ready(function(){
			jQuery('#slider').tabs({ fxFade: true, fxSpeed: 'fast' });
		});
        </script>
	
        <div id="slider" class="wrap">
        
            <ul id="tabs">
			<?php    
            foreach( $tabs as $tab_key => $tab_name )
               echo "\n\t\t<li><a href='#$tab_key'>$tab_name</a></li>";
            ?>
            </ul>
            
            <?php    
            foreach( $tabs as $tab_key => $tab_name )
			{
                echo "\n\t<div id='$tab_key'>\n";
				
                // Looks for the internal class function, otherwise enable a hook for plugins
                if( method_exists( $this, "tab_$tab_key" ) )
                    call_user_func( array( &$this , "tab_$tab_key" ) );
                else
                    do_action( 'bpxs_tab_content_' . $tab_key );
					
                echo "\n\t</div>";
            } 
            ?>
        </div>
        <?php
	}
	
	/**
	 * Create array for tabs and add a filter for other plugins to inject more tabs
	 * @since 1.0
	 */
    function tabs_order()
	{     
    	$tabs = array();
    	
    	$tabs['settings'] = __( 'Settings', 'bpxs' );
    	$tabs['help'] 	  = __( 'Help', 'bpxs' );
    	$tabs['donate']   = __( 'Donate', 'bpxs' );
    	
    	$tabs = apply_filters( 'bpxs_settings_tabs', $tabs );
    
    	return $tabs;
    }

	/**
	 * Content of the General Options tab
	 * @since 1.0
	 */
    function tab_settings()
	{
        global $bpxs;
    	?>
		<script type="text/javascript">
		jQuery(document).ready(function() {
			jQuery('.postbox.close-me').addClass('closed');			
        	jQuery('.postbox h3').click( function() {
				jQuery(this).parent('.postbox').toggleClass('closed');
			});
		});
        </script>
        <h2><?php _e( 'Settings','bpxs' ); ?></h2>

        <form name="general" method="post" action="<?php echo $this->filepath ?>" >
        
            <?php wp_nonce_field( 'bpxs_settings' ) ?>
            <input type="hidden" name="page_options" value="tos,tos_link,signup_title,tos_text,tos_error_text,mcapi_list_id,mcapi_key,newsletter_text,newsletter,email_recipient,email_subject,email_message" />
            <div id="poststuff" class="meta-box-sortables">
                <div class="postbox close-me">
					<div class="handlediv" title="<?php _e( 'Click to toggle', 'bpxs' ) ?>"><br /></div>
                    <h3><?php _e( 'TOS', 'bpxs' ) ?></h3>
                    <div class="inside">
                        <table id="bpxs-tos" class="form-table">
                        <tr>
                            <th><?php _e( 'Activate TOS', 'bpxs' ) ?></th>
                            <td>
                            <select id="bpgs_tos" name="tos">
                                <option <?php selected( true, (bool)$bpxs->options->tos ) ?> value="true"><?php _e( 'Yes', 'bpgs' ) ?></option>
                                <option <?php selected( false, (bool)$bpxs->options->tos ) ?> value="false"><?php _e( 'No', 'bpgs' ) ?></option>
                            </select><br />
                            <small>(<?php _e( 'Show the TOS checkbox on the registration screen?', 'bpxs' ); ?>)</small></td>
                        </tr>
                        <tr>
                            <th><?php _e( 'Signup Title', 'bpxs' ) ?></th>
                            <td>
                                <input type="text" class="large-text" id="bpxs_signup_title" name="signup_title" value="<?php echo stripcslashes( $bpxs->options->signup_title ); ?>" /><br />
                                <small>(<?php _e( 'The header title of the extra signup options.', 'bpxs' ); ?>)</small>
                            </td>
                        </tr>
                        <tr>
                            <th><?php _e( 'Checkbox Text', 'bpxs' ) ?></th>
                            <td>
                                <input type="text" class="large-text" id="bpxs_tos_text" name="tos_text" value="<?php echo stripcslashes( $bpxs->options->tos_text ); ?>" /><br />
                                <small>(<?php _e( 'Will be displayed next to the checkbox a new user needs to check. These placeholders are allowed: {url},{/url}', 'bpxs' ); ?>)</small>
                            </td>
                        </tr>
                        <tr>
                            <th><?php _e( 'TOS Link', 'bpxs' ) ?></th>
                            <td>
                                <input type="text" class="large-text" id="bpxs_tos_link" name="tos_link" value="<?php echo stripcslashes( $bpxs->options->tos_link ); ?>" /><br />
                                <small>(<?php _e( 'The link to your Terms of Service page.', 'bpxs' ); ?>)</small>
                            </td>
                        </tr>
                        <tr>
                            <th><?php _e( 'Error Text', 'bpxs' ) ?></th>
                            <td>
                                <input type="text" class="large-text" id="bpxs_tos_error_text" name="tos_error_text" value="<?php echo stripcslashes( $bpxs->options->tos_error_text ); ?>" /><br />
                                <small>(<?php _e( 'The text that appears when a user does not check the TOS checkbox.', 'bpxs' ); ?>)</small>
                            </td>
                        </tr>
                        </table>
                    </div>
                </div>
                <div class="postbox close-me">
					<div class="handlediv" title="<?php _e( 'Click to toggle', 'bpxs' ) ?>"><br /></div>
                    <h3><?php _e( 'Mailchimp', 'bpxs' ) ?></h3>
                    <div class="inside">
                        <table id="bpxs-newsletter" class="form-table">
                        <tr>
                            <th><?php _e( 'Activate Newsletter', 'bpxs' ) ?></th>
                            <td>
                            <select id="bpgs_newsletter" name="newsletter">
                                <option <?php selected( true, (bool)$bpxs->options->newsletter ) ?> value="true"><?php _e( 'Yes', 'bpgs' ) ?></option>
                                <option <?php selected( false, (bool)$bpxs->options->newsletter ) ?> value="false"><?php _e( 'No', 'bpgs' ) ?></option>
                            </select><br />
                            <small>(<?php _e( 'Only activate the newsletter if you have a Mailchimp account.', 'bpxs' ); ?>)</small></td>
                        </tr>
                        <tr>
                            <th><?php _e( 'Newsletter Text', 'bpxs' ) ?></th>
                            <td>
                                <input type="text" class="large-text" id="bpxs_newsletter_text" name="newsletter_text" value="<?php echo stripcslashes( $bpxs->options->newsletter_text ); ?>" /><br />
                                <small>(<?php _e( 'The text next to the checkbox on the registration page.', 'bpxs' ); ?>)</small>
                            </td>
                        </tr>
                        <tr>
                            <th><?php _e( 'API Key', 'bpxs' ) ?></th>
                            <td>
                                <input type="text" class="large-text" id="bpxs_mcapi_key" name="mcapi_key" value="<?php echo stripcslashes( $bpxs->options->mcapi_key ); ?>" /><br />
                                <small>(<?php _e( 'Your Mailchimp API key.', 'bpxs' ); ?>)</small>
                            </td>
                        </tr>
                        <tr>
                            <th><?php _e( 'List ID', 'bpxs' ) ?></th>
                            <td>
                                <input type="text" class="large-text" id="bpxs_mcapi_list_id" name="mcapi_list_id" value="<?php echo stripcslashes( $bpxs->options->mcapi_list_id ); ?>" /><br />
                                <small>(<?php _e( 'The list ID you want new users to subscribe to.', 'bpxs' ); ?>)</small>
                            </td>
                        </tr>
                        <tr>
                            <th><?php _e( 'Email Recipient', 'bpxs' ) ?></th>
                            <td>
                                <input type="text" class="large-text" id="bpxs_email_recipient" name="email_recipient" value="<?php echo stripcslashes( $bpxs->options->email_recipient ); ?>" /><br />
                                <small>(<?php _e( 'Enter an email address you want newsletter signup errors sent to.', 'bpxs' ); ?>)</small>
                            </td>
                        </tr>
                        <tr>
                            <th><?php _e( 'Email Subject', 'bpxs' ) ?></th>
                            <td>
                                <input type="text" class="large-text" id="bpxs_email_subject" name="email_subject" value="<?php echo stripcslashes( $bpxs->options->email_subject ); ?>" /><br />
                                <small>(<?php _e( 'The subject of the error message.', 'bpxs' ); ?>)</small>
                            </td>
                        </tr>
                        <tr>
                            <th><?php _e( 'Email Message', 'bpxs' ) ?></th>
                            <td>
                                <textarea rows="8" class="large-text" id="bpxs_email_message" name="email_message"><?php echo stripcslashes( $bpxs->options->email_message ); ?></textarea><br />
                                <small>(<?php _e( 'The body of the error message.', 'bpxs' ); ?>)</small>
                            </td>
                        </tr>
                        </table>
                    </div>
                </div>
			</div>      
            <div class="submit"><input type="submit" name="updateoption" value="<?php _e( 'Update' ) ;?> &raquo;"/></div>
        </form>
        <?php	
	}


	/**
	 * Content of the Help tab
	 * @since 1.0
	 */
    function tab_help()
	{
		global $bpxs;

		$shabu = get_option( 'shabu_software' );
			
		$diff = strtotime( date( 'Y-m-d H:i:s' ) ) - strtotime( $shabu['time'] );
		// one ping per day
		$api_time_seconds = 86400;
	
		if( ! $shabu || $diff >= $api_time_seconds )
		{
			if( !class_exists( 'WP_Http' ) )
				include_once( ABSPATH . WPINC. '/class-http.php' );
			
			$request = new WP_Http;
			$http = $request->request( $this->price_url );
			$result = unserialize( $http['body'] );
			
			$shabu_array = array( 'time' => date( 'Y-m-d H:i:s' ), 'info' => $result );
			
			update_option( 'shabu_software', $shabu_array );
		}
		else
			$result = $shabu['info'];

		?>
        
        <h2><?php _e( 'Help', 'bpxs' ); ?></h2>
        
        <p><?php printf( __( 'To receive support for this plugin, please <a href="%s">register</a> on <a href="%s">ShabuShabu.eu</a>.', 'bpxs' ), $bpxs->home_url . 'membership-options/', $bpxs->home_url ); ?></p>
        <p><?php _e( 'Registration is free. Support, however, will only be provided within the support group of this plugin, for which we charge a small monthly subscription fee.', 'bpxs' ); ?></p>

        <table id="bpxs-prices" class="widefat">
            <thead>
            <tr>
                <th class="manage-column" scope="col"><?php _e('Description', 'bpxs' ); ?></th>
                <th class="manage-column" scope="col"><?php _e('Price', 'bpxs' ); ?></th>
            </tr>
            </thead>
        	<?php foreach( $result['prices'] as $desc => $price )
			{
                 $alt = $this->alternate( 'odd', 'even' );
				?>
                <tr class="<?php echo $alt; ?>">
                    <td><?php echo $desc ?></td>
                    <td>EUR <?php echo $price ?></td>
                </tr>
                <?php
			}
			?>
        </table>
        
        <p><?php _e( 'Below you find a list of all our available and planned plugins and themes. Items that have a price tag attached come with 3 months free support.', 'bpxs' ); ?></p>

		<h3><?php _e( 'Plugins', 'bpxs' ) ?></h3>      
        <table class="widefat" cellspacing="0">
            <thead>
            <tr>
                <th class="manage-column" scope="col"><?php _e('Name', 'bpxs' ); ?></th>
                <th class="manage-column" scope="col"><?php _e('Description', 'bpxs' ); ?></th>
                <th class="manage-column" scope="col"><?php _e('Release Date', 'bpxs' ); ?></th>
                <th class="manage-column" scope="col"><?php _e('Price', 'bpxs' ); ?></th>
            </tr>
            </thead>
        
        	<?php foreach( $result['plugins'] as $plugin )
			{
                 $alt = $this->alternate( 'odd', 'even' );
				?>
                <tr class="<?php echo $alt; ?>">
                    <td>
                    <?php if( ! empty( $plugin['url'] ) ) { ?>
                    	<a href="<?php echo $plugin['url']; ?>"><?php echo $plugin['name'] . ' ' . $plugin['version'] ; ?></a>
                    <?php } else { ?>
                    	<?php echo $plugin['name'] . ' ' . $plugin['version'] ; ?>
                    <?php } ?>
                    </td>
                    <td><?php echo $plugin['desc']; ?></td>
                    <td><?php echo $plugin['release']; ?></td>
                    <td><?php echo $plugin['cost']; ?></td>
                </tr>
            <?php } ?>
        </table>

		<h3><?php _e( 'Themes', 'bpxs' ) ?></h3>      
        <table class="widefat" cellspacing="0">
            <thead>
            <tr>
                <th class="manage-column" scope="col"><?php _e('Name', 'bpxs' ); ?></th>
                <th class="manage-column" scope="col"><?php _e('Description', 'bpxs' ); ?></th>
                <th class="manage-column" scope="col"><?php _e('Release Date', 'bpxs' ); ?></th>
                <th class="manage-column" scope="col"><?php _e('Price', 'bpxs' ); ?></th>
            </tr>
            </thead>
        
        	<?php foreach( $result['themes'] as $theme )
			{
                 $alt = $this->alternate( 'odd', 'even' );
				?>
                <tr class="<?php echo $alt; ?>">
                    <td>
                    <?php if( ! empty( $theme['url'] ) ) { ?>
                    	<a href="<?php echo $theme['url']; ?>"><?php echo $theme['name'] . ' ' . $theme['version'] ; ?></a>
                    <?php } else { ?>
                    	<?php echo $theme['name'] . ' ' . $theme['version'] ; ?>
                    <?php } ?>
                    </td>
                    <td><?php echo $theme['desc']; ?></td>
                    <td><?php echo $theme['release']; ?></td>
                    <td><?php echo $theme['cost']; ?></td>
                </tr>
            <?php } ?>
        </table>
        <?php
	}

	/**
	 * Content of the Donate tab
	 * @since 1.0
	 */
    function tab_donate()
	{
		?>
        <h2><?php _e( 'Donate', 'bpxs' ); ?></h2>
        
        <p><?php _e( 'We spend a lot of time and effort on implementing new features and on the maintenance of this plugin, so if you feel generous and have a few bucks to spare, then please consider to donate.', 'bpxs' ); ?></p>
        <p><?php _e( 'Click on the button below and you will be redirected to the PayPal site where you can make a safe donation', 'bpxs' ); ?></p>
        <p>
            <form action="https://www.paypal.com/cgi-bin/webscr" method="post" >
                <input type="hidden" name="cmd" value="_xclick"/><input type="hidden" name="business" value="mail@shabushabu-webbdesign.com"/>
                <input type="hidden" name="item_name" value="<?php _e('BP Xtra Signup @ http://shabushabu.eu','bpxs'); ?>"/>
                <input type="hidden" name="no_shipping" value="1"/><input type="hidden" name="return" value="http://shabushabu.eu/" />
                <input type="hidden" name="cancel_return" value="http://shabushabu.eu/"/>
                <input type="hidden" name="lc" value="US" /> 
                <input type="hidden" name="currency_code" value="USD"/>
                <input type="hidden" name="tax" value="0"/>
                <input type="hidden" name="bn" value="PP-DonationsBF"/>
                <input type="image" src="https://www.paypal.com/en_US/i/btn/x-click-but21.gif" name="submit" alt="<?php _e( 'Make payments with PayPal - it\'s fast, free and secure!', 'bpxs' ); ?>" style="border: none;"/>
            </form>
        </p>
        <p><?php _e( 'Thank you and all the best!' ,'bpxs' ); ?><br />ShabuShabu Webdesign Team</p>
        <?php
	}

	/**
	 * alternate between anything
	 * @since 1.0
	 */
	function alternate()
	{
		static $i = 0;
		$args = func_get_args();
	
		return $args[$i++ % (func_num_args())];
	}
}
?>